from setuptools import setup, find_packages

setup(
    name="elastic-logger-custom",
    version="1.0.7",
    install_requires=[
        "elasticsearch>=7.0.0,<8.0.0",
        'python-dotenv~=1.0.1',
    ],
    description="A custom logging handler for Elasticsearch",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    packages=find_packages(),
)